voicetools.Voice
================

.. abjad-lineage:: abjad.tools.voicetools.Voice.Voice.Voice

.. autoclass:: abjad.tools.voicetools.Voice.Voice.Voice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.descendants
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.leaves
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.lineage
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.music
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.override
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.parent
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.parentage
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.prolation
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.set
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.spanners
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.start_offset
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.timespan
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.context_name
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.append
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.extend
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.index
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.insert
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.pop
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__add__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__contains__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__delitem__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__eq__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__ge__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__getitem__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__gt__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__iadd__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__imul__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__le__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__len__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__lt__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__mul__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__ne__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__radd__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__repr__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__rmul__
   :noindex:

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__setitem__
   :noindex:
